# Welcome to wellwiz


[![image](https://img.shields.io/pypi/v/wellwiz.svg)](https://pypi.python.org/pypi/wellwiz)


**A developing python package to gather information about the gas and oil wells and know the risk through a map visualization.**


-   Free software: MIT License
-   Documentation: <https://OmiimO05.github.io/wellwiz>
    

## Features

-   TODO
